summaryrefslogtreecommitdiffstats
path: root/konqueror
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-15 19:15:16 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-02-15 19:15:16 +0000
commitcc0ad49c75d6cf6b4e63eb8c6012afe55c1589f9 (patch)
tree2a29ccab4d3cea34b87bfcbc38e64a8e25d25bb0 /konqueror
parent107dd1f98367d07df7cbe2042786511e44706d3a (diff)
downloadtdebase-cc0ad49c75d6cf6b4e63eb8c6012afe55c1589f9.tar.gz
tdebase-cc0ad49c75d6cf6b4e63eb8c6012afe55c1589f9.zip
Allow kdebase to (mostly) function correctly with TQt for Qt4
Fix kicker tackbar handling under Classic mode (thanks to Ilya Chernykh for the patch) Fix a newly invalidated section of code under GCC 4.5.2 (http://gcc.gnu.org/bugzilla/show_bug.cgi?id=47723#c6) git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1220927 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konqueror')
-rw-r--r--konqueror/about/konq_aboutpage.cc332
-rw-r--r--konqueror/iconview/konq_iconview.cc18
-rw-r--r--konqueror/keditbookmarks/actionsimpl.cpp4
-rw-r--r--konqueror/keditbookmarks/toplevel.cpp4
-rw-r--r--konqueror/konq_actions.cc18
-rw-r--r--konqueror/konq_actions.h2
-rw-r--r--konqueror/konq_combo.cc20
-rw-r--r--konqueror/konq_frame.cc7
-rw-r--r--konqueror/konq_mainwindow.cc6
-rw-r--r--konqueror/konq_run.cc4
-rw-r--r--konqueror/konq_tabs.cc36
-rw-r--r--konqueror/konq_view.cc34
-rw-r--r--konqueror/konq_view.h8
-rw-r--r--konqueror/konq_viewmgr.cc36
-rw-r--r--konqueror/kttsplugin/khtmlkttsd.cpp4
-rw-r--r--konqueror/listview/konq_infolistviewwidget.cc8
-rw-r--r--konqueror/listview/konq_listview.cc2
-rw-r--r--konqueror/listview/konq_listviewitems.cc2
-rw-r--r--konqueror/listview/konq_listviewwidget.cc24
-rw-r--r--konqueror/listview/konq_listviewwidget.h3
-rw-r--r--konqueror/listview/konq_textviewwidget.cc8
-rw-r--r--konqueror/listview/konq_treeviewwidget.cc8
-rw-r--r--konqueror/remoteencodingplugin/kremoteencodingplugin.cpp2
-rw-r--r--konqueror/shellcmdplugin/kshellcmdplugin.cpp2
-rw-r--r--konqueror/sidebar/konqsidebar.h3
-rw-r--r--konqueror/sidebar/konqsidebarplugin.cpp2
-rw-r--r--konqueror/sidebar/sidebar_widget.cpp30
-rw-r--r--konqueror/sidebar/trees/bookmark_module/bookmark_module.cpp6
-rw-r--r--konqueror/sidebar/trees/konq_sidebartree.cpp4
-rw-r--r--konqueror/sidebar/trees/konqsidebar_tree.cpp2
30 files changed, 323 insertions, 316 deletions
diff --git a/konqueror/about/konq_aboutpage.cc b/konqueror/about/konq_aboutpage.cc
index 6291b72d5..05b0d19e9 100644
--- a/konqueror/about/konq_aboutpage.cc
+++ b/konqueror/about/konq_aboutpage.cc
@@ -54,7 +54,7 @@ KParts::Part *KonqAboutPageFactory::createPartObject( TQWidget *tqparentWidget,
TQObject *parent, const char *name,
const char *, const TQStringList & )
{
- //KonqFrame *frame = dynamic_cast<KonqFrame *>( tqparentWidget );
+ //KonqFrame *frame = tqt_dynamic_cast<KonqFrame *>( tqparentWidget );
//if ( !frame ) return 0;
return new KonqAboutPage( //frame->childView()->mainWindow(),
@@ -110,11 +110,11 @@ TQString KonqAboutPageFactory::launch()
TQString home_folder = TQDir::homeDirPath();
TQString continue_icon_path = TQApplication::reverseLayout()?iconloader->iconPath("1leftarrow", KIcon::Small ):iconloader->iconPath("1rightarrow", KIcon::Small );
- res = res.arg( locate( "data", "kdeui/about/kde_infopage.css" ) );
+ res = res.tqarg( locate( "data", "kdeui/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- res = res.arg( "@import \"%1\";" ).arg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
+ res = res.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
else
- res = res.arg( "" );
+ res = res.tqarg( "" );
// Try to split page in three. If it succeeds, insert the default search into the middle part.
TQStringList parts = TQStringList::split( "<!--search bar splitter-->", res );
@@ -123,56 +123,56 @@ TQString KonqAboutPageFactory::launch()
config.setGroup( "General" );
TQString name = config.readEntry("DefaultSearchEngine");
KService::Ptr service =
- KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").arg(name));
+ KService::serviceByDesktopPath(TQString("searchproviders/%1.desktop").tqarg(name));
if ( service ) {
TQString searchBar = parts[1];
searchBar = searchBar
- .arg( iconSize ).arg( iconSize )
- .arg( service->name() )
- .arg( service->property("Keys").toStringList()[0] )
+ .tqarg( iconSize ).tqarg( iconSize )
+ .tqarg( service->name() )
+ .tqarg( service->property("Keys").toStringList()[0] )
;
res = parts[0] + searchBar + parts[2];
}
else res = parts[0] + parts[2];
}
- res = res.arg( i18n("Conquer your Desktop!") )
- .arg( i18n( "Konqueror" ) )
- .arg( i18n("Conquer your Desktop!") )
- .arg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
- .arg( i18n( "Starting Points" ) )
- .arg( i18n( "Introduction" ) )
- .arg( i18n( "Tips" ) )
- .arg( i18n( "Specifications" ) )
- .arg( home_folder )
- .arg( home_icon_path )
- .arg(iconSize).arg(iconSize)
- .arg( home_folder )
- .arg( i18n( "Home Folder" ) )
- .arg( i18n( "Your personal files" ) )
- .arg( storage_icon_path )
- .arg(iconSize).arg(iconSize)
- .arg( i18n( "Storage Media" ) )
- .arg( i18n( "Disks and removable media" ) )
- .arg( remote_icon_path )
- .arg(iconSize).arg(iconSize)
- .arg( i18n( "Network Folders" ) )
- .arg( i18n( "Shared files and folders" ) )
- .arg( wastebin_icon_path )
- .arg(iconSize).arg(iconSize)
- .arg( i18n( "Trash" ) )
- .arg( i18n( "Browse and restore the trash" ) )
- .arg( applications_icon_path )
- .arg(iconSize).arg(iconSize)
- .arg( i18n( "Applications" ) )
- .arg( i18n( "Installed programs" ) )
- .arg( help_icon_path )
- .arg(iconSize).arg(iconSize)
- .arg( i18n( "About Kubuntu" ) )
- .arg( i18n( "<a href=\"help:/kubuntu/\">Kubuntu Documentation</a>" ) )
- .arg( continue_icon_path )
- .arg( KIcon::SizeSmall ).arg( KIcon::SizeSmall )
- .arg( i18n( "Next: An Introduction to Konqueror" ) )
+ res = res.tqarg( i18n("Conquer your Desktop!") )
+ .tqarg( i18n( "Konqueror" ) )
+ .tqarg( i18n("Conquer your Desktop!") )
+ .tqarg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
+ .tqarg( i18n( "Starting Points" ) )
+ .tqarg( i18n( "Introduction" ) )
+ .tqarg( i18n( "Tips" ) )
+ .tqarg( i18n( "Specifications" ) )
+ .tqarg( home_folder )
+ .tqarg( home_icon_path )
+ .tqarg(iconSize).tqarg(iconSize)
+ .tqarg( home_folder )
+ .tqarg( i18n( "Home Folder" ) )
+ .tqarg( i18n( "Your personal files" ) )
+ .tqarg( storage_icon_path )
+ .tqarg(iconSize).tqarg(iconSize)
+ .tqarg( i18n( "Storage Media" ) )
+ .tqarg( i18n( "Disks and removable media" ) )
+ .tqarg( remote_icon_path )
+ .tqarg(iconSize).tqarg(iconSize)
+ .tqarg( i18n( "Network Folders" ) )
+ .tqarg( i18n( "Shared files and folders" ) )
+ .tqarg( wastebin_icon_path )
+ .tqarg(iconSize).tqarg(iconSize)
+ .tqarg( i18n( "Trash" ) )
+ .tqarg( i18n( "Browse and restore the trash" ) )
+ .tqarg( applications_icon_path )
+ .tqarg(iconSize).tqarg(iconSize)
+ .tqarg( i18n( "Applications" ) )
+ .tqarg( i18n( "Installed programs" ) )
+ .tqarg( help_icon_path )
+ .tqarg(iconSize).tqarg(iconSize)
+ .tqarg( i18n( "About Kubuntu" ) )
+ .tqarg( i18n( "<a href=\"help:/kubuntu/\">Kubuntu Documentation</a>" ) )
+ .tqarg( continue_icon_path )
+ .tqarg( KIcon::SizeSmall ).tqarg( KIcon::SizeSmall )
+ .tqarg( i18n( "Next: An Introduction to Konqueror" ) )
;
i18n("Search the Web");//i18n for possible future use
@@ -195,42 +195,42 @@ TQString KonqAboutPageFactory::intro()
TQString gohome_icon_path = iconloader->iconPath("gohome", KIcon::Small );
TQString continue_icon_path = TQApplication::reverseLayout()?iconloader->iconPath("1leftarrow", KIcon::Small ):iconloader->iconPath("1rightarrow", KIcon::Small );
- res = res.arg( locate( "data", "kdeui/about/kde_infopage.css" ) );
+ res = res.tqarg( locate( "data", "kdeui/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- res = res.arg( "@import \"%1\";" ).arg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
+ res = res.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
else
- res = res.arg( "" );
-
- res = res.arg( i18n("Conquer your Desktop!") )
- .arg( i18n( "Konqueror" ) )
- .arg( i18n( "Conquer your Desktop!") )
- .arg( i18n( "Konqueror is your file manager, web browser and universal document viewer.") )
- .arg( i18n( "Starting Points" ) )
- .arg( i18n( "Introduction" ) )
- .arg( i18n( "Tips" ) )
- .arg( i18n( "Specifications" ) )
- .arg( i18n( "Konqueror makes working with and managing your files easy. You can browse "
+ res = res.tqarg( "" );
+
+ res = res.tqarg( i18n("Conquer your Desktop!") )
+ .tqarg( i18n( "Konqueror" ) )
+ .tqarg( i18n( "Conquer your Desktop!") )
+ .tqarg( i18n( "Konqueror is your file manager, web browser and universal document viewer.") )
+ .tqarg( i18n( "Starting Points" ) )
+ .tqarg( i18n( "Introduction" ) )
+ .tqarg( i18n( "Tips" ) )
+ .tqarg( i18n( "Specifications" ) )
+ .tqarg( i18n( "Konqueror makes working with and managing your files easy. You can browse "
"both local and networked folders while enjoying advanced features "
"such as the powerful sidebar and file previews."
) )
- .arg( i18n( "Konqueror is also a full featured and easy to use web browser which you "
+ .tqarg( i18n( "Konqueror is also a full featured and easy to use web browser which you "
"can use to explore the Internet. "
"Enter the address (e.g. <a href=\"http://www.kde.org\">http://www.kde.org</A>) "
"of a web page you would like to visit in the location bar and press Enter, "
"or choose an entry from the Bookmarks menu.") )
- .arg( i18n( "To return to the previous "
+ .tqarg( i18n( "To return to the previous "
"location, press the back button <img width='16' height='16' src=\"%1\"> "
- "in the toolbar. ").arg( back_icon_path ) )
- .arg( i18n( "To quickly go to your Home folder press the "
- " home button <img width='16' height='16' src=\"%1\">." ).arg(gohome_icon_path) )
- .arg( i18n( "For more detailed documentation on Konqueror click <a href=\"%1\">here</a>." )
- .arg("exec:/khelpcenter") )
- .arg( i18n( "<em>Tuning Tip:</em> If you want the Konqueror web browser to start faster,"
+ "in the toolbar. ").tqarg( back_icon_path ) )
+ .tqarg( i18n( "To quickly go to your Home folder press the "
+ " home button <img width='16' height='16' src=\"%1\">." ).tqarg(gohome_icon_path) )
+ .tqarg( i18n( "For more detailed documentation on Konqueror click <a href=\"%1\">here</a>." )
+ .tqarg("exec:/khelpcenter") )
+ .tqarg( i18n( "<em>Tuning Tip:</em> If you want the Konqueror web browser to start faster,"
" you can turn off this information screen by clicking <a href=\"%1\">here</a>. You can re-enable it"
" by choosing the Help -> Konqueror Introduction menu option, and then pressing "
- "Settings -> Save View Profile \"Web Browsing\".").arg("config:/disable_overview") )
- .arg( "<img width='16' height='16' src=\"%1\">" ).arg( continue_icon_path )
- .arg( i18n( "Next: Tips &amp; Tricks" ) )
+ "Settings -> Save View Profile \"Web Browsing\".").tqarg("config:/disable_overview") )
+ .tqarg( "<img width='16' height='16' src=\"%1\">" ).tqarg( continue_icon_path )
+ .tqarg( i18n( "Next: Tips &amp; Tricks" ) )
;
@@ -250,69 +250,69 @@ TQString KonqAboutPageFactory::specs()
if ( res.isEmpty() )
return res;
- res = res.arg( locate( "data", "kdeui/about/kde_infopage.css" ) );
+ res = res.tqarg( locate( "data", "kdeui/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- res = res.arg( "@import \"%1\";" ).arg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
+ res = res.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
else
- res = res.arg( "" );
-
- res = res.arg( i18n("Conquer your Desktop!") )
- .arg( i18n( "Konqueror" ) )
- .arg( i18n("Conquer your Desktop!") )
- .arg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
- .arg( i18n( "Starting Points" ) )
- .arg( i18n( "Introduction" ) )
- .arg( i18n( "Tips" ) )
- .arg( i18n( "Specifications" ) )
- .arg( i18n("Specifications") )
- .arg( i18n("Konqueror is designed to embrace and support Internet standards. "
+ res = res.tqarg( "" );
+
+ res = res.tqarg( i18n("Conquer your Desktop!") )
+ .tqarg( i18n( "Konqueror" ) )
+ .tqarg( i18n("Conquer your Desktop!") )
+ .tqarg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
+ .tqarg( i18n( "Starting Points" ) )
+ .tqarg( i18n( "Introduction" ) )
+ .tqarg( i18n( "Tips" ) )
+ .tqarg( i18n( "Specifications" ) )
+ .tqarg( i18n("Specifications") )
+ .tqarg( i18n("Konqueror is designed to embrace and support Internet standards. "
"The aim is to fully implement the officially sanctioned standards "
"from organizations such as the W3 and OASIS, while also adding "
"extra support for other common usability features that arise as "
"de facto standards across the Internet. Along with this support, "
"for such functions as favicons, Internet Keywords, and <A HREF=\"%1\">XBEL bookmarks</A>, "
- "Konqueror also implements:").arg("http://pyxml.sourceforge.net/topics/xbel/") )
- .arg( i18n("Web Browsing") )
- .arg( i18n("Supported standards") )
- .arg( i18n("Additional requirements*") )
- .arg( i18n("<A HREF=\"%1\">DOM</A> (Level 1, partially Level 2) based "
- "<A HREF=\"%2\">HTML 4.01</A>").arg("http://www.w3.org/DOM").arg("http://www.w3.org/TR/html4/") )
- .arg( i18n("built-in") )
- .arg( i18n("<A HREF=\"%1\">Cascading Style Sheets</A> (CSS 1, partially CSS 2)").arg("http://www.w3.org/Style/CSS/") )
- .arg( i18n("built-in") )
- .arg( i18n("<A HREF=\"%1\">ECMA-262</A> Edition 3 (roughly equals JavaScript 1.5)").arg("http://www.ecma.ch/ecma1/STAND/ECMA-262.HTM") )
- .arg( i18n("JavaScript disabled (globally). Enable JavaScript <A HREF=\"%1\">here</A>.").arg("exec:/kcmshell khtml_java_js") )
- .arg( i18n("JavaScript enabled (globally). Configure JavaScript <A HREF=\\\"%1\\\">here</A>.").arg("exec:/kcmshell khtml_java_js") ) // leave the double backslashes here, they are necessary for javascript !
- .arg( i18n("Secure <A HREF=\"%1\">Java</A><SUP>&reg;</SUP> support").arg("http://java.sun.com") )
- .arg( i18n("JDK 1.2.0 (Java 2) compatible VM (<A HREF=\"%1\">Blackdown</A>, <A HREF=\"%2\">IBM</A> or <A HREF=\"%3\">Sun</A>)")
- .arg("http://www.blackdown.org").arg("http://www.ibm.com").arg("http://java.sun.com") )
- .arg( i18n("Enable Java (globally) <A HREF=\"%1\">here</A>.").arg("exec:/kcmshell khtml_java_js") ) // TODO Maybe test if Java is enabled ?
- .arg( i18n("Netscape Communicator<SUP>&reg;</SUP> <A HREF=\"%4\">plugins</A> (for viewing <A HREF=\"%1\">Flash<SUP>&reg;</SUP></A>, <A HREF=\"%2\">Real<SUP>&reg;</SUP></A>Audio, <A HREF=\"%3\">Real<SUP>&reg;</SUP></A>Video, etc.)")
- .arg("http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash")
- .arg("http://www.real.com").arg("http://www.real.com")
- .arg("about:plugins") )
- .arg( i18n("built-in") )
- .arg( i18n("Secure Sockets Layer") )
- .arg( i18n("(TLS/SSL v2/3) for secure communications up to 168bit") )
- .arg( i18n("OpenSSL") )
- .arg( i18n("Bidirectional 16bit tqunicode support") )
- .arg( i18n("built-in") )
- .arg( i18n("AutoCompletion for forms") )
- .arg( i18n("built-in") )
- .arg( i18n("G E N E R A L") )
- .arg( i18n("Feature") )
- .arg( i18n("Details") )
- .arg( i18n("Image formats") )
- .arg( i18n("Transfer protocols") )
- .arg( i18n("HTTP 1.1 (including gzip/bzip2 compression)") )
- .arg( i18n("FTP") )
- .arg( i18n("and <A HREF=\"%1\">many more...</A>").arg("exec:/kcmshell ioslaveinfo") )
- .arg( i18n("URL-Completion") )
- .arg( i18n("Manual"))
- .arg( i18n("Popup"))
- .arg( i18n("(Short-) Automatic"))
- .arg( "<img width='16' height='16' src=\"%1\">" ).arg( continue_icon_path )
- .arg( i18n("<a href=\"%1\">Return to Starting Points</a>").arg("launch.html") )
+ "Konqueror also implements:").tqarg("http://pyxml.sourceforge.net/topics/xbel/") )
+ .tqarg( i18n("Web Browsing") )
+ .tqarg( i18n("Supported standards") )
+ .tqarg( i18n("Additional requirements*") )
+ .tqarg( i18n("<A HREF=\"%1\">DOM</A> (Level 1, partially Level 2) based "
+ "<A HREF=\"%2\">HTML 4.01</A>").tqarg("http://www.w3.org/DOM").tqarg("http://www.w3.org/TR/html4/") )
+ .tqarg( i18n("built-in") )
+ .tqarg( i18n("<A HREF=\"%1\">Cascading Style Sheets</A> (CSS 1, partially CSS 2)").tqarg("http://www.w3.org/Style/CSS/") )
+ .tqarg( i18n("built-in") )
+ .tqarg( i18n("<A HREF=\"%1\">ECMA-262</A> Edition 3 (roughly equals JavaScript 1.5)").tqarg("http://www.ecma.ch/ecma1/STAND/ECMA-262.HTM") )
+ .tqarg( i18n("JavaScript disabled (globally). Enable JavaScript <A HREF=\"%1\">here</A>.").tqarg("exec:/kcmshell khtml_java_js") )
+ .tqarg( i18n("JavaScript enabled (globally). Configure JavaScript <A HREF=\\\"%1\\\">here</A>.").tqarg("exec:/kcmshell khtml_java_js") ) // leave the double backslashes here, they are necessary for javascript !
+ .tqarg( i18n("Secure <A HREF=\"%1\">Java</A><SUP>&reg;</SUP> support").tqarg("http://java.sun.com") )
+ .tqarg( i18n("JDK 1.2.0 (Java 2) compatible VM (<A HREF=\"%1\">Blackdown</A>, <A HREF=\"%2\">IBM</A> or <A HREF=\"%3\">Sun</A>)")
+ .tqarg("http://www.blackdown.org").tqarg("http://www.ibm.com").tqarg("http://java.sun.com") )
+ .tqarg( i18n("Enable Java (globally) <A HREF=\"%1\">here</A>.").tqarg("exec:/kcmshell khtml_java_js") ) // TODO Maybe test if Java is enabled ?
+ .tqarg( i18n("Netscape Communicator<SUP>&reg;</SUP> <A HREF=\"%4\">plugins</A> (for viewing <A HREF=\"%1\">Flash<SUP>&reg;</SUP></A>, <A HREF=\"%2\">Real<SUP>&reg;</SUP></A>Audio, <A HREF=\"%3\">Real<SUP>&reg;</SUP></A>Video, etc.)")
+ .tqarg("http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash")
+ .tqarg("http://www.real.com").tqarg("http://www.real.com")
+ .tqarg("about:plugins") )
+ .tqarg( i18n("built-in") )
+ .tqarg( i18n("Secure Sockets Layer") )
+ .tqarg( i18n("(TLS/SSL v2/3) for secure communications up to 168bit") )
+ .tqarg( i18n("OpenSSL") )
+ .tqarg( i18n("Bidirectional 16bit tqunicode support") )
+ .tqarg( i18n("built-in") )
+ .tqarg( i18n("AutoCompletion for forms") )
+ .tqarg( i18n("built-in") )
+ .tqarg( i18n("G E N E R A L") )
+ .tqarg( i18n("Feature") )
+ .tqarg( i18n("Details") )
+ .tqarg( i18n("Image formats") )
+ .tqarg( i18n("Transfer protocols") )
+ .tqarg( i18n("HTTP 1.1 (including gzip/bzip2 compression)") )
+ .tqarg( i18n("FTP") )
+ .tqarg( i18n("and <A HREF=\"%1\">many more...</A>").tqarg("exec:/kcmshell ioslaveinfo") )
+ .tqarg( i18n("URL-Completion") )
+ .tqarg( i18n("Manual"))
+ .tqarg( i18n("Popup"))
+ .tqarg( i18n("(Short-) Automatic"))
+ .tqarg( "<img width='16' height='16' src=\"%1\">" ).tqarg( continue_icon_path )
+ .tqarg( i18n("<a href=\"%1\">Return to Starting Points</a>").tqarg("launch.html") )
;
@@ -347,57 +347,57 @@ TQString KonqAboutPageFactory::tips()
iconloader->iconPath("view_left_right", KIcon::Small );
TQString continue_icon_path = TQApplication::reverseLayout()?iconloader->iconPath("1leftarrow", KIcon::Small ):iconloader->iconPath("1rightarrow", KIcon::Small );
- res = res.arg( locate( "data", "kdeui/about/kde_infopage.css" ) );
+ res = res.tqarg( locate( "data", "kdeui/about/kde_infopage.css" ) );
if ( kapp->reverseLayout() )
- res = res.arg( "@import \"%1\";" ).arg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
+ res = res.tqarg( "@import \"%1\";" ).tqarg( locate( "data", "kdeui/about/kde_infopage_rtl.css" ) );
else
- res = res.arg( "" );
-
- res = res.arg( i18n("Conquer your Desktop!") )
- .arg( i18n( "Konqueror" ) )
- .arg( i18n("Conquer your Desktop!") )
- .arg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
- .arg( i18n( "Starting Points" ) )
- .arg( i18n( "Introduction" ) )
- .arg( i18n( "Tips" ) )
- .arg( i18n( "Specifications" ) )
- .arg( i18n( "Tips &amp; Tricks" ) )
- .arg( i18n( "Use Internet-Keywords and Web-Shortcuts: by typing \"gg: KDE\" one can search the Internet, "
+ res = res.tqarg( "" );
+
+ res = res.tqarg( i18n("Conquer your Desktop!") )
+ .tqarg( i18n( "Konqueror" ) )
+ .tqarg( i18n("Conquer your Desktop!") )
+ .tqarg( i18n("Konqueror is your file manager, web browser and universal document viewer.") )
+ .tqarg( i18n( "Starting Points" ) )
+ .tqarg( i18n( "Introduction" ) )
+ .tqarg( i18n( "Tips" ) )
+ .tqarg( i18n( "Specifications" ) )
+ .tqarg( i18n( "Tips &amp; Tricks" ) )
+ .tqarg( i18n( "Use Internet-Keywords and Web-Shortcuts: by typing \"gg: KDE\" one can search the Internet, "
"using Google, for the search phrase \"KDE\". There are a lot of "
"Web-Shortcuts predefined to make searching for software or looking "
"up certain words in an encyclopedia a breeze. You can even "
- "<a href=\"%1\">create your own</a> Web-Shortcuts." ).arg("exec:/kcmshell ebrowsing") )
- .arg( i18n( "Use the magnifier button <img width='16' height='16' src=\"%1\"> in the"
- " toolbar to increase the font size on your web page.").arg(viewmag_icon_path) )
- .arg( i18n( "When you want to paste a new address into the Location toolbar you might want to "
+ "<a href=\"%1\">create your own</a> Web-Shortcuts." ).tqarg("exec:/kcmshell ebrowsing") )
+ .tqarg( i18n( "Use the magnifier button <img width='16' height='16' src=\"%1\"> in the"
+ " toolbar to increase the font size on your web page.").tqarg(viewmag_icon_path) )
+ .tqarg( i18n( "When you want to paste a new address into the Location toolbar you might want to "
"clear the current entry by pressing the black arrow with the white cross "
"<img width='16' height='16' src=\"%1\"> in the toolbar.")
- .arg(TQApplication::reverseLayout() ? locationbar_erase_rtl_icon_path : locationbar_erase_icon_path))
- .arg( i18n( "To create a link on your desktop pointing to the current page, "
+ .tqarg(TQApplication::reverseLayout() ? locationbar_erase_rtl_icon_path : locationbar_erase_icon_path))
+ .tqarg( i18n( "To create a link on your desktop pointing to the current page, "
"simply drag the \"Location\" label that is to the left of the Location toolbar, drop it on to "
"the desktop, and choose \"Link\"." ) )
- .arg( i18n( "You can also find <img width='16' height='16' src=\"%1\"> \"Full-Screen Mode\" "
+ .tqarg( i18n( "You can also find <img width='16' height='16' src=\"%1\"> \"Full-Screen Mode\" "
"in the Settings menu. This feature is very useful for \"Talk\" "
- "sessions.").arg(window_fullscreen_icon_path) )
- .arg( i18n( "Divide et impera (lat. \"Divide and conquer\") - by splitting a window "
+ "sessions.").tqarg(window_fullscreen_icon_path) )
+ .tqarg( i18n( "Divide et impera (lat. \"Divide and conquer\") - by splitting a window "
"into two parts (e.g. Window -> <img width='16' height='16' src=\"%1\"> Split View "
"Left/Right) you can make Konqueror appear the way you like. You"
" can even load some example view-profiles (e.g. Midnight Commander)"
- ", or create your own ones." ).arg(view_left_right_icon_path))
- .arg( i18n( "Use the <a href=\"%1\">user-agent</a> feature if the website you are visiting "
+ ", or create your own ones." ).tqarg(view_left_right_icon_path))
+ .tqarg( i18n( "Use the <a href=\"%1\">user-agent</a> feature if the website you are visiting "
"asks you to use a different browser "
- "(and do not forget to send a complaint to the webmaster!)" ).arg("exec:/kcmshell useragent") )
- .arg( i18n( "The <img width='16' height='16' src=\"%1\"> History in your SideBar ensures "
- "that you can keep track of the pages you have visited recently.").arg(history_icon_path) )
- .arg( i18n( "Use a caching <a href=\"%1\">proxy</a> to speed up your"
- " Internet connection.").arg("exec:/kcmshell proxy") )
- .arg( i18n( "Advanced users will appreciate the Konsole which you can embed into "
+ "(and do not forget to send a complaint to the webmaster!)" ).tqarg("exec:/kcmshell useragent") )
+ .tqarg( i18n( "The <img width='16' height='16' src=\"%1\"> History in your SideBar ensures "
+ "that you can keep track of the pages you have visited recently.").tqarg(history_icon_path) )
+ .tqarg( i18n( "Use a caching <a href=\"%1\">proxy</a> to speed up your"
+ " Internet connection.").tqarg("exec:/kcmshell proxy") )
+ .tqarg( i18n( "Advanced users will appreciate the Konsole which you can embed into "
"Konqueror (Window -> <img width='16' height='16' SRC=\"%1\"> Show "
- "Terminal Emulator).").arg(openterm_icon_path))
- .arg( i18n( "Thanks to <a href=\"%1\">DCOP</a> you can have full control over Konqueror using a script."
-).arg("exec:/kdcop") )
- .arg( i18n( "<img width='16' height='16' src=\"%1\">" ).arg( continue_icon_path ) )
- .arg( i18n( "Next: Specifications" ) )
+ "Terminal Emulator).").tqarg(openterm_icon_path))
+ .tqarg( i18n( "Thanks to <a href=\"%1\">DCOP</a> you can have full control over Konqueror using a script."
+).tqarg("exec:/kdcop") )
+ .tqarg( i18n( "<img width='16' height='16' src=\"%1\">" ).tqarg( continue_icon_path ) )
+ .tqarg( i18n( "Next: Specifications" ) )
;
@@ -413,10 +413,10 @@ TQString KonqAboutPageFactory::plugins()
return *s_plugins_html;
TQString res = loadFile( locate( "data", kapp->reverseLayout() ? "konqueror/about/plugins_rtl.html" : "konqueror/about/plugins.html" ))
- .arg(i18n("Installed Plugins"))
- .arg(i18n("<td>Plugin</td><td>Description</td><td>File</td><td>Types</td>"))
- .arg(i18n("Installed"))
- .arg(i18n("<td>Mime Type</td><td>Description</td><td>Suffixes</td><td>Plugin</td>"));
+ .tqarg(i18n("Installed Plugins"))
+ .tqarg(i18n("<td>Plugin</td><td>Description</td><td>File</td><td>Types</td>"))
+ .tqarg(i18n("Installed"))
+ .tqarg(i18n("<td>Mime Type</td><td>Description</td><td>Suffixes</td><td>Plugin</td>"));
if ( res.isEmpty() )
return res;
@@ -489,7 +489,7 @@ void KonqAboutPage::restoreState( TQDataStream &stream )
void KonqAboutPage::serve( const TQString& html, const TQString& what )
{
m_what = what;
- begin( KURL( TQString("about:%1").arg(what) ) );
+ begin( KURL( TQString("about:%1").tqarg(what) ) );
write( html );
end();
m_htmlDoc = html;
diff --git a/konqueror/iconview/konq_iconview.cc b/konqueror/iconview/konq_iconview.cc
index f9129ce71..87eba006d 100644
--- a/konqueror/iconview/konq_iconview.cc
+++ b/konqueror/iconview/konq_iconview.cc
@@ -273,7 +273,7 @@ KonqKfmIconView::KonqKfmIconView( TQWidget *tqparentWidget, TQObject *parent, co
//enable menu item representing the saved sorting criterion
TQString sortcrit = KonqIconViewFactory::defaultViewProps()->sortCriterion();
- KRadioAction *sort_action = dynamic_cast<KRadioAction *>(actionCollection()->action(sortcrit.latin1()));
+ KRadioAction *sort_action = tqt_dynamic_cast<KRadioAction *>(actionCollection()->action(sortcrit.latin1()));
if(sort_action!=NULL) sort_action->activate();
m_paSortDirsFirst = new KToggleAction( i18n( "Folders First" ), 0, actionCollection(), "sort_directoriesfirst" );
@@ -872,7 +872,7 @@ void KonqKfmIconView::slotCanceled( const KURL& url )
// the completed() signal, so handle that case.
if ( !m_pIconView->viewport()->isUpdatesEnabled() )
{
- m_pIconView->viewport()->setUpdatesEnabled( true );
+ m_pIconView->viewport()->tqsetUpdatesEnabled( true );
m_pIconView->viewport()->tqrepaint();
}
if ( m_pEnsureVisible ){
@@ -892,7 +892,7 @@ void KonqKfmIconView::slotCompleted()
// not been called), a viewport tqrepaint is forced.
if ( !m_pIconView->viewport()->isUpdatesEnabled() )
{
- m_pIconView->viewport()->setUpdatesEnabled( true );
+ m_pIconView->viewport()->tqsetUpdatesEnabled( true );
m_pIconView->viewport()->tqrepaint();
}
@@ -952,7 +952,7 @@ void KonqKfmIconView::slotNewItems( const KFileItemList& entries )
// We need to disable graphics updates on the iconview when
// inserting items, or else a blank paint operation will be
// performed on the top-left corner for each inserted item!
- m_pIconView->setUpdatesEnabled( false );
+ m_pIconView->tqsetUpdatesEnabled( false );
for (KFileItemListIterator it(entries); it.current(); ++it)
{
//kdDebug(1202) << "KonqKfmIconView::slotNewItem(...)" << _fileitem->url().url() << endl;
@@ -1006,11 +1006,11 @@ void KonqKfmIconView::slotNewItems( const KFileItemList& entries )
m_itemDict.insert( *it, item );
}
// After filtering out updates-on-insertions we can re-enable updates
- m_pIconView->setUpdatesEnabled( true );
+ m_pIconView->tqsetUpdatesEnabled( true );
// Locking the viewport has filtered out blanking and now, since we
// have some items to draw, we can restore updating.
if ( !m_pIconView->viewport()->isUpdatesEnabled() )
- m_pIconView->viewport()->setUpdatesEnabled( true );
+ m_pIconView->viewport()->tqsetUpdatesEnabled( true );
KonqDirPart::newItems( entries );
}
@@ -1150,7 +1150,7 @@ void KonqKfmIconView::slotClear()
// meaningless paint operations (such as a clear() just before drawing
// fresh contents) we disable updating the viewport until we'll
// receive some data or a timeout timer expires.
- m_pIconView->viewport()->setUpdatesEnabled( false );
+ m_pIconView->viewport()->tqsetUpdatesEnabled( false );
if ( !m_pTimeoutRefreshTimer )
{
m_pTimeoutRefreshTimer = new TQTimer( this );
@@ -1247,9 +1247,9 @@ void KonqKfmIconView::slotRefreshViewport()
kdDebug(1202) << "KonqKfmIconView::slotRefreshViewport()" << endl;
TQWidget * vp = m_pIconView->viewport();
bool prevState = vp->isUpdatesEnabled();
- vp->setUpdatesEnabled( true );
+ vp->tqsetUpdatesEnabled( true );
vp->tqrepaint();
- vp->setUpdatesEnabled( prevState );
+ vp->tqsetUpdatesEnabled( prevState );
}
bool KonqKfmIconView::doOpenURL( const KURL & url )
diff --git a/konqueror/keditbookmarks/actionsimpl.cpp b/konqueror/keditbookmarks/actionsimpl.cpp
index bbfb548ad..1f03665d4 100644
--- a/konqueror/keditbookmarks/actionsimpl.cpp
+++ b/konqueror/keditbookmarks/actionsimpl.cpp
@@ -345,7 +345,7 @@ void ActionsImpl::slotCopy() {
TQValueList<KBookmark> bookmarks
= ListView::self()->itemsToBookmarks(ListView::self()->selectedItemsMap());
KBookmarkDrag* data = KBookmarkDrag::newDrag(bookmarks, 0 /* not this ! */);
- kapp->tqclipboard()->setData(data, QClipboard::Clipboard);
+ kapp->tqclipboard()->setData(data, TQClipboard::Clipboard);
}
void ActionsImpl::slotPaste() {
@@ -353,7 +353,7 @@ void ActionsImpl::slotPaste() {
KEBMacroCommand *mcmd =
CmdGen::insertMimeSource(
i18n("Paste"),
- kapp->tqclipboard()->data(QClipboard::Clipboard),
+ kapp->tqclipboard()->data(TQClipboard::Clipboard),
ListView::self()->userAddress());
CmdHistory::self()->didCommand(mcmd);
}
diff --git a/konqueror/keditbookmarks/toplevel.cpp b/konqueror/keditbookmarks/toplevel.cpp
index ce2d9db58..0cc8f823f 100644
--- a/konqueror/keditbookmarks/toplevel.cpp
+++ b/konqueror/keditbookmarks/toplevel.cpp
@@ -247,7 +247,7 @@ KEBApp::KEBApp(
m_dcopIface = new KBookmarkEditorIface();
- connect(kapp->clipboard(), TQT_SIGNAL( dataChanged() ),
+ connect(kapp->tqclipboard(), TQT_SIGNAL( dataChanged() ),
TQT_SLOT( slotClipboardDataChanged() ));
ListView::self()->connectSignals();
@@ -319,7 +319,7 @@ void KEBApp::slotClipboardDataChanged() {
// kdDebug() << "KEBApp::slotClipboardDataChanged" << endl;
if (!m_readOnly) {
m_canPaste = KBookmarkDrag::canDecode(
- kapp->tqclipboard()->data(QClipboard::Clipboard));
+ kapp->tqclipboard()->data(TQClipboard::Clipboard));
updateActions();
}
}
diff --git a/konqueror/konq_actions.cc b/konqueror/konq_actions.cc
index 35c5fec83..047066040 100644
--- a/konqueror/konq_actions.cc
+++ b/konqueror/konq_actions.cc
@@ -48,12 +48,12 @@ void KonqBidiHistoryAction::fillHistoryPopup( const TQPtrList<HistoryEntry> &his
{
assert ( popup ); // kill me if this 0... :/
- //kdDebug(1202) << "fillHistoryPopup position: " << history.at() << endl;
+ //kdDebug(1202) << "fillHistoryPopup position: " << history.tqat() << endl;
HistoryEntry * current = history.current();
TQPtrListIterator<HistoryEntry> it( history );
if (onlyBack || onlyForward)
{
- it += history.at(); // Jump to current item
+ it += history.tqat(); // Jump to current item
if ( !onlyForward ) --it; else ++it; // And move off it
} else if ( startPos )
it += startPos; // Jump to specified start pos
@@ -75,7 +75,7 @@ void KonqBidiHistoryAction::fillHistoryPopup( const TQPtrList<HistoryEntry> &his
break;
if ( !onlyForward ) --it; else ++it;
}
- //kdDebug(1202) << "After fillHistoryPopup position: " << history.at() << endl;
+ //kdDebug(1202) << "After fillHistoryPopup position: " << history.tqat() << endl;
}
///////////////////////////////
@@ -116,7 +116,7 @@ void KonqBidiHistoryAction::fillGoMenu( const TQPtrList<HistoryEntry> & history
if (history.isEmpty())
return; // nothing to do
- //kdDebug(1202) << "fillGoMenu position: " << history.at() << endl;
+ //kdDebug(1202) << "fillGoMenu position: " << history.tqat() << endl;
if ( m_firstIndex == 0 ) // should never happen since done in plug
m_firstIndex = m_goMenu->count();
else
@@ -136,10 +136,10 @@ void KonqBidiHistoryAction::fillGoMenu( const TQPtrList<HistoryEntry> & history
// Second case: big history, in one or both directions
{
// Assume both directions first (in this case we place the current URL in the middle)
- m_startPos = history.at() + 4;
+ m_startPos = history.tqat() + 4;
// Forward not big enough ?
- if ( history.at() > (int)history.count() - 4 )
+ if ( history.tqat() > (int)history.count() - 4 )
m_startPos = history.count() - 1;
}
Q_ASSERT( m_startPos >= 0 && (uint)m_startPos < history.count() );
@@ -148,7 +148,7 @@ void KonqBidiHistoryAction::fillGoMenu( const TQPtrList<HistoryEntry> & history
kdWarning() << "m_startPos=" << m_startPos << " history.count()=" << history.count() << endl;
return;
}
- m_currentPos = history.at(); // for slotActivated
+ m_currentPos = history.tqat(); // for slotActivated
KonqBidiHistoryAction::fillHistoryPopup( history, m_goMenu, false, false, true, m_startPos );
}
@@ -444,7 +444,7 @@ void KonqMostOftenURLSAction::slotFillMenu()
m_popupList.clear();
int id = s_mostEntries->count() -1;
- KonqHistoryEntry *entry = s_mostEntries->at( id );
+ KonqHistoryEntry *entry = s_mostEntries->tqat( id );
while ( entry ) {
// we take either title, typedURL or URL (in this order)
TQString text = entry->title.isEmpty() ? (entry->typedURL.isEmpty() ?
@@ -459,7 +459,7 @@ void KonqMostOftenURLSAction::slotFillMenu()
// This prevents crashes when another process tells us to remove an entry.
m_popupList.prepend( entry->url );
- entry = (id > 0) ? s_mostEntries->at( --id ) : 0L;
+ entry = (id > 0) ? s_mostEntries->tqat( --id ) : 0L;
}
setEnabled( !s_mostEntries->isEmpty() );
Q_ASSERT( s_mostEntries->count() == m_popupList.count() );
diff --git a/konqueror/konq_actions.h b/konqueror/konq_actions.h
index 849d45668..41dbdad71 100644
--- a/konqueror/konq_actions.h
+++ b/konqueror/konq_actions.h
@@ -62,7 +62,7 @@ signals:
private:
uint m_firstIndex; // first index in the Go menu
int m_startPos;
- int m_currentPos; // == history.at()
+ int m_currentPos; // == history.tqat()
TQPopupMenu *m_goMenu; // hack
};
diff --git a/konqueror/konq_combo.cc b/konqueror/konq_combo.cc
index 9bd39a86e..0f13236e5 100644
--- a/konqueror/konq_combo.cc
+++ b/konqueror/konq_combo.cc
@@ -272,14 +272,14 @@ void KonqCombo::updateItem( const TQPixmap& pix, const TQString& t, int index, c
listBox()->changeItem( item, index );
/*
- setUpdatesEnabled( false );
- lineEdit()->setUpdatesEnabled( false );
+ tqsetUpdatesEnabled( false );
+ lineEdit()->tqsetUpdatesEnabled( false );
removeItem( index );
insertItem( pix, t, index );
- setUpdatesEnabled( true );
- lineEdit()->setUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
+ lineEdit()->tqsetUpdatesEnabled( true );
update();
*/
}
@@ -301,12 +301,12 @@ void KonqCombo::updatePixmaps()
{
saveState();
- setUpdatesEnabled( false );
+ tqsetUpdatesEnabled( false );
KonqPixmapProvider *prov = KonqPixmapProvider::self();
for ( int i = 1; i < count(); i++ ) {
updateItem( prov->pixmapFor( text( i ) ), text( i ), i, titleOfURL( text( i ) ) );
}
- setUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
tqrepaint();
restoreState();
@@ -521,15 +521,15 @@ void KonqCombo::slotRemoved( const TQString& item )
void KonqCombo::removeURL( const TQString& url )
{
- setUpdatesEnabled( false );
- lineEdit()->setUpdatesEnabled( false );
+ tqsetUpdatesEnabled( false );
+ lineEdit()->tqsetUpdatesEnabled( false );
removeFromHistory( url );
applyPermanent();
setTemporary( currentText() );
- setUpdatesEnabled( true );
- lineEdit()->setUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
+ lineEdit()->tqsetUpdatesEnabled( true );
update();
}
diff --git a/konqueror/konq_frame.cc b/konqueror/konq_frame.cc
index 965fcec06..d8c80b234 100644
--- a/konqueror/konq_frame.cc
+++ b/konqueror/konq_frame.cc
@@ -460,8 +460,11 @@ void KonqFrame::slotLinkedViewClicked( bool mode )
void
KonqFrame::paintEvent( TQPaintEvent* )
{
-// m_pStatusBar->tqrepaint();
- m_pStatusBar->update();
+#ifdef USE_QT4
+ #warning [INFO] Repaint call disabled in Qt4 to prevent recursive repaint (which otherwise occurs for unknown reasons)
+#else // USE_QT4
+ m_pStatusBar->tqrepaint();
+#endif // USE_QT4
}
void KonqFrame::slotRemoveView()
diff --git a/konqueror/konq_mainwindow.cc b/konqueror/konq_mainwindow.cc
index ed06539e5..f162c0b60 100644
--- a/konqueror/konq_mainwindow.cc
+++ b/konqueror/konq_mainwindow.cc
@@ -3495,7 +3495,7 @@ bool KonqMainWindow::eventFilter(TQObject*obj,TQEvent *ev)
connect( m_paCut, TQT_SIGNAL( activated() ), m_combo->lineEdit(), TQT_SLOT( cut() ) );
connect( m_paCopy, TQT_SIGNAL( activated() ), m_combo->lineEdit(), TQT_SLOT( copy() ) );
connect( m_paPaste, TQT_SIGNAL( activated() ), m_combo->lineEdit(), TQT_SLOT( paste() ) );
- connect( TQApplication::clipboard(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotClipboardDataChanged()) );
+ connect( TQApplication::tqclipboard(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotClipboardDataChanged()) );
connect( m_combo->lineEdit(), TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotCheckComboSelection()) );
connect( m_combo->lineEdit(), TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotCheckComboSelection()) );
@@ -3536,7 +3536,7 @@ bool KonqMainWindow::eventFilter(TQObject*obj,TQEvent *ev)
disconnect( m_paCut, TQT_SIGNAL( activated() ), m_combo->lineEdit(), TQT_SLOT( cut() ) );
disconnect( m_paCopy, TQT_SIGNAL( activated() ), m_combo->lineEdit(), TQT_SLOT( copy() ) );
disconnect( m_paPaste, TQT_SIGNAL( activated() ), m_combo->lineEdit(), TQT_SLOT( paste() ) );
- disconnect( TQApplication::clipboard(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotClipboardDataChanged()) );
+ disconnect( TQApplication::tqclipboard(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(slotClipboardDataChanged()) );
disconnect( m_combo->lineEdit(), TQT_SIGNAL(textChanged(const TQString &)), this, TQT_SLOT(slotCheckComboSelection()) );
disconnect( m_combo->lineEdit(), TQT_SIGNAL(selectionChanged()), this, TQT_SLOT(slotCheckComboSelection()) );
@@ -3584,7 +3584,7 @@ void KonqMainWindow::slotClearLocationBar( KAction::ActivationReason, TQt::Butto
m_combo->clearTemporary();
focusLocationBar();
if ( state & Qt::MidButton )
- m_combo->setURL( TQApplication::clipboard()->text( QClipboard::Selection ) );
+ m_combo->setURL( TQApplication::tqclipboard()->text( TQClipboard::Selection ) );
}
void KonqMainWindow::slotForceSaveMainWindowSettings()
diff --git a/konqueror/konq_run.cc b/konqueror/konq_run.cc
index fbac4e65c..a23513bd0 100644
--- a/konqueror/konq_run.cc
+++ b/konqueror/konq_run.cc
@@ -148,7 +148,7 @@ void KonqRun::init()
KParts::BrowserRun::init();
// Maybe init went to the "let's try stat'ing" part. Then connect to info messages.
// (in case it goes to scanFile, this will be done below)
- KIO::StatJob *job = dynamic_cast<KIO::StatJob*>( m_job );
+ KIO::StatJob *job = tqt_dynamic_cast<KIO::StatJob*>( m_job );
if ( job && !job->error() && m_pView ) {
connect( job, TQT_SIGNAL( infoMessage( KIO::Job*, const TQString& ) ),
m_pView, TQT_SLOT( slotInfoMessage(KIO::Job*, const TQString& ) ) );
@@ -160,7 +160,7 @@ void KonqRun::scanFile()
KParts::BrowserRun::scanFile();
// could be a static cast as of now, but who would notify when
// BrowserRun changes
- KIO::TransferJob *job = dynamic_cast<KIO::TransferJob*>( m_job );
+ KIO::TransferJob *job = tqt_dynamic_cast<KIO::TransferJob*>( m_job );
if ( job && !job->error() ) {
connect( job, TQT_SIGNAL( redirection( KIO::Job *, const KURL& )),
TQT_SLOT( slotRedirection( KIO::Job *, const KURL& ) ));
diff --git a/konqueror/konq_view.cc b/konqueror/konq_view.cc
index e7f1bd7bf..d23982437 100644
--- a/konqueror/konq_view.cc
+++ b/konqueror/konq_view.cc
@@ -227,7 +227,7 @@ void KonqView::openURL( const KURL &url, const TQString & locationBarURL,
KonqHistoryManager::kself()->addPending( url, locationBarURL, TQString::null);
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "Current position : " << m_lstHistory.at() << endl;
+ kdDebug(1202) << "Current position : " << m_lstHistory.tqat() << endl;
#endif
}
@@ -711,7 +711,7 @@ void KonqView::createHistoryEntry()
#ifdef DEBUG_HISTORY
kdDebug(1202) << "Truncating history" << endl;
#endif
- m_lstHistory.at( m_lstHistory.count() - 1 ); // go to last one
+ m_lstHistory.tqat( m_lstHistory.count() - 1 ); // go to last one
for ( ; m_lstHistory.current() != current ; )
{
if ( !m_lstHistory.removeLast() ) // and remove from the end (faster and easier)
@@ -720,7 +720,7 @@ void KonqView::createHistoryEntry()
// makes current() null if it's the last item. however in qt2
// the behaviour was different than the documentation. this is
// changed in qt3 to behave as documented ;-) (Simon)
- m_lstHistory.at( m_lstHistory.count() - 1 );
+ m_lstHistory.tqat( m_lstHistory.count() - 1 );
}
// Now current is the current again.
}
@@ -730,9 +730,9 @@ void KonqView::createHistoryEntry()
#endif
m_lstHistory.append( new HistoryEntry ); // made current
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "at=" << m_lstHistory.at() << " count=" << m_lstHistory.count() << endl;
+ kdDebug(1202) << "at=" << m_lstHistory.tqat() << " count=" << m_lstHistory.count() << endl;
#endif
- assert( m_lstHistory.at() == (int) m_lstHistory.count() - 1 );
+ assert( m_lstHistory.tqat() == (int) m_lstHistory.count() - 1 );
}
void KonqView::updateHistoryEntry( bool saveLocationBarURL )
@@ -752,20 +752,20 @@ void KonqView::updateHistoryEntry( bool saveLocationBarURL )
}
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "Saving part URL : " << m_pPart->url() << " in history position " << m_lstHistory.at() << endl;
+ kdDebug(1202) << "Saving part URL : " << m_pPart->url() << " in history position " << m_lstHistory.tqat() << endl;
#endif
current->url = m_pPart->url();
if (saveLocationBarURL)
{
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "Saving location bar URL : " << m_sLocationBarURL << " in history position " << m_lstHistory.at() << endl;
+ kdDebug(1202) << "Saving location bar URL : " << m_sLocationBarURL << " in history position " << m_lstHistory.tqat() << endl;
#endif
current->locationBarURL = m_sLocationBarURL;
current->pageSecurity = m_pageSecurity;
}
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "Saving title : " << m_caption << " in history position " << m_lstHistory.at() << endl;
+ kdDebug(1202) << "Saving title : " << m_caption << " in history position " << m_lstHistory.tqat() << endl;
#endif
current->title = m_caption;
current->strServiceType = m_serviceType;
@@ -800,7 +800,7 @@ void KonqView::go( int steps )
return;
}
- int newPos = m_lstHistory.at() + steps;
+ int newPos = m_lstHistory.tqat() + steps;
#ifdef DEBUG_HISTORY
kdDebug(1202) << "go : steps=" << steps
<< " newPos=" << newPos
@@ -813,13 +813,13 @@ void KonqView::go( int steps )
stop();
// Yay, we can move there without a loop !
- HistoryEntry *currentHistoryEntry = m_lstHistory.at( newPos ); // sets current item
+ HistoryEntry *currentHistoryEntry = m_lstHistory.tqat( newPos ); // sets current item
assert( currentHistoryEntry );
- assert( newPos == m_lstHistory.at() ); // check we moved (i.e. if I understood the docu)
+ assert( newPos == m_lstHistory.tqat() ); // check we moved (i.e. if I understood the docu)
assert( currentHistoryEntry == m_lstHistory.current() );
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "New position " << m_lstHistory.at() << endl;
+ kdDebug(1202) << "New position " << m_lstHistory.tqat() << endl;
#endif
restoreHistory();
@@ -866,7 +866,7 @@ void KonqView::restoreHistory()
m_pMainWindow->updateToolBarActions();
#ifdef DEBUG_HISTORY
- kdDebug(1202) << "New position (2) " << m_lstHistory.at() << endl;
+ kdDebug(1202) << "New position (2) " << m_lstHistory.tqat() << endl;
#endif
}
@@ -874,9 +874,9 @@ const HistoryEntry * KonqView::historyAt(const int pos)
{
if(pos<0 || pos>=(int)m_lstHistory.count())
return 0L;
- int oldpos = m_lstHistory.at();
- const HistoryEntry* h = m_lstHistory.at(pos);
- m_lstHistory.at( oldpos );
+ int oldpos = m_lstHistory.tqat();
+ const HistoryEntry* h = m_lstHistory.tqat(pos);
+ m_lstHistory.tqat( oldpos );
return h;
}
@@ -887,7 +887,7 @@ void KonqView::copyHistory( KonqView *other )
TQPtrListIterator<HistoryEntry> it( other->m_lstHistory );
for (; it.current(); ++it )
m_lstHistory.append( new HistoryEntry( *it.current() ) );
- m_lstHistory.at(other->m_lstHistory.at());
+ m_lstHistory.tqat(other->m_lstHistory.tqat());
}
KURL KonqView::url() const
diff --git a/konqueror/konq_view.h b/konqueror/konq_view.h
index 1329000f8..d251da53b 100644
--- a/konqueror/konq_view.h
+++ b/konqueror/konq_view.h
@@ -125,17 +125,17 @@ public:
/**
* @return true if view can go back
*/
- bool canGoBack()const { return m_lstHistory.at() > 0; }
+ bool canGoBack()const { return m_lstHistory.tqat() > 0; }
/**
* @return true if view can go forward
*/
- bool canGoForward()const { return m_lstHistory.at() != ((int)m_lstHistory.count())-1; }
+ bool canGoForward()const { return m_lstHistory.tqat() != ((int)m_lstHistory.count())-1; }
/**
* @return the position in the history
*/
- int historyPos() const { return m_lstHistory.at(); }
+ int historyPos() const { return m_lstHistory.tqat(); }
uint historyLength() { return m_lstHistory.count(); }
@@ -149,7 +149,7 @@ public:
*/
void restoreHistory();
- void setHistoryPos(int newPos) { m_lstHistory.at( newPos ); }
+ void setHistoryPos(int newPos) { m_lstHistory.tqat( newPos ); }
/**
* @return the history of this view
diff --git a/konqueror/konq_viewmgr.cc b/konqueror/konq_viewmgr.cc
index 86fb3d478..d2600adf1 100644
--- a/konqueror/konq_viewmgr.cc
+++ b/konqueror/konq_viewmgr.cc
@@ -132,7 +132,7 @@ KonqView* KonqViewManager::splitView ( Qt::Orientation orientation,
//printSizeInfo( splitFrame, parentContainer, "before split");
#endif
- parentContainer->widget()->setUpdatesEnabled( false );
+ parentContainer->widget()->tqsetUpdatesEnabled( false );
//kdDebug(1202) << "Move out child" << endl;
TQPoint pos = splitFrame->widget()->pos();
@@ -184,7 +184,7 @@ KonqView* KonqViewManager::splitView ( Qt::Orientation orientation,
//newView->frame()->show();
newContainer->show();
- parentContainer->widget()->setUpdatesEnabled( true );
+ parentContainer->widget()->tqsetUpdatesEnabled( true );
if (m_pDocContainer == splitFrame) m_pDocContainer = newContainer;
@@ -226,7 +226,7 @@ KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation,
KonqFrameBase* mainFrame = m_pMainWindow->childFrame();
- mainFrame->widget()->setUpdatesEnabled( false );
+ mainFrame->widget()->tqsetUpdatesEnabled( false );
//kdDebug(1202) << "Move out child" << endl;
TQPoint pos = mainFrame->widget()->pos();
@@ -249,7 +249,7 @@ KonqView* KonqViewManager::splitWindow( Qt::Orientation orientation,
newContainer->show();
- mainFrame->widget()->setUpdatesEnabled( true );
+ mainFrame->widget()->tqsetUpdatesEnabled( true );
if( childView )
childView->openURL( url, locationBarURL );
@@ -279,7 +279,7 @@ void KonqViewManager::convertDocContainer()
splitterSizes = static_cast<KonqFrameContainer*>(parentContainer)->sizes();
}
- parentContainer->widget()->setUpdatesEnabled( false );
+ parentContainer->widget()->tqsetUpdatesEnabled( false );
//kdDebug(1202) << "Move out child" << endl;
TQPoint pos = m_pDocContainer->widget()->pos();
@@ -302,7 +302,7 @@ void KonqViewManager::convertDocContainer()
newContainer->show();
- parentContainer->widget()->setUpdatesEnabled( true );
+ parentContainer->widget()->tqsetUpdatesEnabled( true );
m_pDocContainer = newContainer;
}
@@ -410,7 +410,7 @@ void KonqViewManager::duplicateTab( KonqFrameBase* tab, bool openAfterCurrentPag
KonqFrameBase* currentFrame;
if ( tab == 0L )
- currentFrame = dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
+ currentFrame = tqt_dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
else
currentFrame = tab;
@@ -451,7 +451,7 @@ void KonqViewManager::duplicateTab( KonqFrameBase* tab, bool openAfterCurrentPag
else
tabContainer->setCurrentPage( tabContainer->count() - 1 );
- KonqFrameBase* duplicatedFrame = dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
+ KonqFrameBase* duplicatedFrame = tqt_dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
if (duplicatedFrame)
duplicatedFrame->copyHistory( currentFrame );
@@ -480,7 +480,7 @@ void KonqViewManager::breakOffTab( KonqFrameBase* tab )
KonqFrameBase* currentFrame;
if ( tab == 0L )
- currentFrame = dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
+ currentFrame = tqt_dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
else
currentFrame = tab;
@@ -508,7 +508,7 @@ void KonqViewManager::breakOffTab( KonqFrameBase* tab )
if( newDocContainer && newDocContainer->frameType() == "Tabs")
{
KonqFrameTabs *kft = static_cast<KonqFrameTabs *>(newDocContainer);
- KonqFrameBase *newFrame = dynamic_cast<KonqFrameBase*>(kft->currentPage());
+ KonqFrameBase *newFrame = tqt_dynamic_cast<KonqFrameBase*>(kft->currentPage());
if(newFrame)
newFrame->copyHistory( currentFrame );
}
@@ -553,7 +553,7 @@ void KonqViewManager::removeTab( KonqFrameBase* tab )
if ( tab != 0L ) {
currentFrame = tab;
} else {
- currentFrame = dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
+ currentFrame = tqt_dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
if (!currentFrame) {
return;
}
@@ -622,7 +622,7 @@ void KonqViewManager::removeOtherTabs( KonqFrameBase* tab )
KonqFrameBase *currentFrame;
if ( tab == 0L )
- currentFrame = dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
+ currentFrame = tqt_dynamic_cast<KonqFrameBase*>(tabContainer->currentPage());
else
currentFrame = tab;
@@ -784,7 +784,7 @@ void KonqViewManager::removeView( KonqView *view )
if (m_pDocContainer == parentContainer) m_pDocContainer = otherFrame;
- grandParentContainer->widget()->setUpdatesEnabled( false );
+ grandParentContainer->widget()->tqsetUpdatesEnabled( false );
static_cast<KonqFrameContainer*>(parentContainer)->setAboutToBeDeleted();
//kdDebug(1202) << "--- Reparenting otherFrame to m_pMainWindow " << m_pMainWindow << endl;
@@ -826,7 +826,7 @@ void KonqViewManager::removeView( KonqView *view )
grandParentContainer->setActiveChild( otherFrame );
grandParentContainer->activateChild();
- grandParentContainer->widget()->setUpdatesEnabled( true );
+ grandParentContainer->widget()->tqsetUpdatesEnabled( true );
}
else if (parentContainer->frameType()=="Tabs") {
kdDebug(1202) << "parentContainer " << parentContainer << " is a KonqFrameTabs" << endl;
@@ -1611,8 +1611,8 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
if (cfg.readBoolEntry( TQString::tqfromLatin1( "docContainer" ).prepend( prefix ), false ))
m_pDocContainer = newContainer;
- loadItem( cfg, newContainer, childList.at(0), defaultURL, openURL );
- loadItem( cfg, newContainer, childList.at(1), defaultURL, openURL );
+ loadItem( cfg, newContainer, childList.tqat(0), defaultURL, openURL );
+ loadItem( cfg, newContainer, childList.tqat(1), defaultURL, openURL );
newContainer->setSizes( sizes );
@@ -1642,7 +1642,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
loadItem( cfg, newContainer, *it, defaultURL, openURL );
TQWidget* currentPage = newContainer->currentPage();
if (currentPage != 0L) {
- KonqView* activeChildView = dynamic_cast<KonqFrameBase*>(currentPage)->activeChildView();
+ KonqView* activeChildView = tqt_dynamic_cast<KonqFrameBase*>(currentPage)->activeChildView();
if (activeChildView != 0L) {
activeChildView->setCaption( activeChildView->caption() );
activeChildView->setTabIcon( activeChildView->url() );
@@ -1650,7 +1650,7 @@ void KonqViewManager::loadItem( KConfig &cfg, KonqFrameContainerBase *parent,
}
}
- newContainer->setActiveChild( dynamic_cast<KonqFrameBase*>(newContainer->page(index)) );
+ newContainer->setActiveChild( tqt_dynamic_cast<KonqFrameBase*>(newContainer->page(index)) );
newContainer->setCurrentPage( index );
newContainer->show();
diff --git a/konqueror/kttsplugin/khtmlkttsd.cpp b/konqueror/kttsplugin/khtmlkttsd.cpp
index e832bd27a..1ddba4d93 100644
--- a/konqueror/kttsplugin/khtmlkttsd.cpp
+++ b/konqueror/kttsplugin/khtmlkttsd.cpp
@@ -118,13 +118,13 @@ void KHTMLPluginKTTSD::slotReadOut()
}
// kdDebug() << "KHTMLPluginKTTSD::slotReadOut: query = " << query << endl;
- dataBuf.at(0); // reset data
+ dataBuf.tqat(0); // reset data
arg << query << "";
if ( !client->call("kttsd", "KSpeech", "setText(TQString,TQString)",
data, replyType, replyData, true) )
TQMessageBox::warning( 0, i18n( "DCOP Call Failed" ),
i18n( "The DCOP call setText failed." ));
- dataBuf.at(0);
+ dataBuf.tqat(0);
arg << 0;
if ( !client->call("kttsd", "KSpeech", "startText(uint)",
data, replyType, replyData, true) )
diff --git a/konqueror/listview/konq_infolistviewwidget.cc b/konqueror/listview/konq_infolistviewwidget.cc
index 135e11a09..eb11d0c22 100644
--- a/konqueror/listview/konq_infolistviewwidget.cc
+++ b/konqueror/listview/konq_infolistviewwidget.cc
@@ -181,8 +181,8 @@ void KonqInfoListViewWidget::rebuildView()
if ( !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
}
@@ -215,8 +215,8 @@ void KonqInfoListViewWidget::slotNewItems( const KFileItemList& list)
if ( !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
diff --git a/konqueror/listview/konq_listview.cc b/konqueror/listview/konq_listview.cc
index 3307073de..a01a7aa2c 100644
--- a/konqueror/listview/konq_listview.cc
+++ b/konqueror/listview/konq_listview.cc
@@ -169,7 +169,7 @@ void ListViewBrowserExtension::rename()
const TQString txt = le->text();
TQString pattern;
KMimeType::diagnoseFileName( txt, pattern );
- if (!pattern.isEmpty() && pattern.at(0)=='*' && pattern.tqfind('*',1)==-1)
+ if (!pattern.isEmpty() && pattern.tqat(0)=='*' && pattern.tqfind('*',1)==-1)
le->setSelection(0, txt.length()-pattern.stripWhiteSpace().length()+1);
else
{
diff --git a/konqueror/listview/konq_listviewitems.cc b/konqueror/listview/konq_listviewitems.cc
index a66dbb06c..a8f92c0d3 100644
--- a/konqueror/listview/konq_listviewitems.cc
+++ b/konqueror/listview/konq_listviewitems.cc
@@ -234,7 +234,7 @@ const TQPixmap* KonqListViewItem::pixmap( int column ) const
if ((int)m_pixmaps.count() <= column)
return 0;
- TQPixmap *pm = m_pixmaps.at( column, &ok );
+ TQPixmap *pm = m_pixmaps.tqat( column, &ok );
if( !ok )
return 0;
return pm;
diff --git a/konqueror/listview/konq_listviewwidget.cc b/konqueror/listview/konq_listviewwidget.cc
index d61518767..a39796579 100644
--- a/konqueror/listview/konq_listviewwidget.cc
+++ b/konqueror/listview/konq_listviewwidget.cc
@@ -259,7 +259,7 @@ void KonqBaseListViewWidget::readProtocolConfig( const KURL & url )
//search the column in confColumns
for ( unsigned int j = 0; j < NumberOfAtoms; j++ )
{
- if ( confColumns[j].name == *lstColumns.at(i) )
+ if ( confColumns[j].name == *lstColumns.tqat(i) )
{
confColumns[j].displayThisOne = true;
confColumns[j].displayInColumn = currentColumn;
@@ -268,7 +268,7 @@ void KonqBaseListViewWidget::readProtocolConfig( const KURL & url )
currentColumn++;
if ( i < lstColumnWidths.count() )
- confColumns[j].width = *lstColumnWidths.at(i);
+ confColumns[j].width = *lstColumnWidths.tqat(i);
else
{
// Default Column widths
@@ -984,7 +984,7 @@ void KonqBaseListViewWidget::slotReturnPressed( TQListViewItem *_item )
if (_item->pixmap(0) != 0)
{
- // Rect of the QListViewItem's pixmap area.
+ // Rect of the TQListViewItem's pixmap area.
TQRect rect = _item->listView()->tqitemRect(_item);
// calculate nesting depth
@@ -1192,8 +1192,8 @@ void KonqBaseListViewWidget::setComplete()
if ( !isUpdatesEnabled() || !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
@@ -1237,8 +1237,8 @@ void KonqBaseListViewWidget::slotClear()
m_pBrowserView->resetCount();
m_pBrowserView->lstPendingMimeIconItems().clear();
- viewport()->setUpdatesEnabled( false );
- setUpdatesEnabled( false );
+ viewport()->tqsetUpdatesEnabled( false );
+ tqsetUpdatesEnabled( false );
clear();
}
@@ -1268,8 +1268,8 @@ void KonqBaseListViewWidget::slotNewItems( const KFileItemList & entries )
if ( !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
slotUpdateBackground();
@@ -1301,7 +1301,7 @@ void KonqBaseListViewWidget::slotDeleteItem( KFileItem * _fileitem )
}
delete &(*it);
- // HACK HACK HACK: QListViewItem/KonqBaseListViewItem should
+ // HACK HACK HACK: TQListViewItem/KonqBaseListViewItem should
// take care and the source looks like it does; till the
// real bug is found, this fixes some crashes (malte)
emit selectionChanged();
@@ -1314,8 +1314,8 @@ void KonqBaseListViewWidget::slotDeleteItem( KFileItem * _fileitem )
// OK, but this code also gets activated when deleting a hidden file... (dfaure)
if ( !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
slotUpdateBackground();
diff --git a/konqueror/listview/konq_listviewwidget.h b/konqueror/listview/konq_listviewwidget.h
index 7d57c202f..0ad11fc17 100644
--- a/konqueror/listview/konq_listviewwidget.h
+++ b/konqueror/listview/konq_listviewwidget.h
@@ -80,6 +80,7 @@ class KonqBaseListViewWidget : public KListView
friend class ListViewBrowserExtension;
Q_OBJECT
+ TQ_OBJECT
public:
KonqBaseListViewWidget( KonqListView *parent, TQWidget *tqparentWidget );
virtual ~KonqBaseListViewWidget();
@@ -161,7 +162,7 @@ public slots:
protected slots:
void slotAutoScroll();
- // from QListView
+ // from TQListView
virtual void slotReturnPressed( TQListViewItem *_item );
virtual void slotCurrentChanged( TQListViewItem *_item ) { slotOnItem( _item ); }
diff --git a/konqueror/listview/konq_textviewwidget.cc b/konqueror/listview/konq_textviewwidget.cc
index f3e9140d3..2012b6480 100644
--- a/konqueror/listview/konq_textviewwidget.cc
+++ b/konqueror/listview/konq_textviewwidget.cc
@@ -101,8 +101,8 @@ void KonqTextViewWidget::slotNewItems( const KFileItemList & entries )
if ( !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
slotUpdateBackground();
@@ -146,8 +146,8 @@ void KonqTextViewWidget::setComplete()
if ( !isUpdatesEnabled() || !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
}
diff --git a/konqueror/listview/konq_treeviewwidget.cc b/konqueror/listview/konq_treeviewwidget.cc
index 5fefc8133..1f19cf979 100644
--- a/konqueror/listview/konq_treeviewwidget.cc
+++ b/konqueror/listview/konq_treeviewwidget.cc
@@ -121,8 +121,8 @@ void KonqTreeViewWidget::slotCompleted( const KURL & _url )
if ( !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
}
@@ -268,8 +268,8 @@ void KonqTreeViewWidget::slotNewItems( const KFileItemList &entries )
if ( !viewport()->isUpdatesEnabled() )
{
- viewport()->setUpdatesEnabled( true );
- setUpdatesEnabled( true );
+ viewport()->tqsetUpdatesEnabled( true );
+ tqsetUpdatesEnabled( true );
triggerUpdate();
}
diff --git a/konqueror/remoteencodingplugin/kremoteencodingplugin.cpp b/konqueror/remoteencodingplugin/kremoteencodingplugin.cpp
index f8ca47992..596408d88 100644
--- a/konqueror/remoteencodingplugin/kremoteencodingplugin.cpp
+++ b/konqueror/remoteencodingplugin/kremoteencodingplugin.cpp
@@ -55,7 +55,7 @@ KRemoteEncodingPlugin::KRemoteEncodingPlugin(TQObject * parent,
m_menu->setEnabled(false);
m_menu->setDelayed(false);
- m_part = dynamic_cast<KonqDirPart*>(parent);
+ m_part = tqt_dynamic_cast<KonqDirPart*>(parent);
if (m_part)
// if parent is not a KonqDirPart, our menu will never show
TQObject::connect(m_part, TQT_SIGNAL(aboutToOpenURL()),
diff --git a/konqueror/shellcmdplugin/kshellcmdplugin.cpp b/konqueror/shellcmdplugin/kshellcmdplugin.cpp
index 7c39fb826..66dd0b7bb 100644
--- a/konqueror/shellcmdplugin/kshellcmdplugin.cpp
+++ b/konqueror/shellcmdplugin/kshellcmdplugin.cpp
@@ -39,7 +39,7 @@ KShellCmdPlugin::KShellCmdPlugin( TQObject* parent, const char* name,
void KShellCmdPlugin::slotExecuteShellCommand()
{
- KonqDirPart * part = dynamic_cast<KonqDirPart *>(parent());
+ KonqDirPart * part = tqt_dynamic_cast<KonqDirPart *>(parent());
if ( !part )
{
KMessageBox::sorry(0L, "KShellCmdPlugin::slotExecuteShellCommand: Program error, please report a bug.");
diff --git a/konqueror/sidebar/konqsidebar.h b/konqueror/sidebar/konqsidebar.h
index 2724b2d39..0d8bf89ea 100644
--- a/konqueror/sidebar/konqsidebar.h
+++ b/konqueror/sidebar/konqsidebar.h
@@ -37,6 +37,7 @@ class KonqSidebarFactory;
class KonqSidebarBrowserExtension : public KParts::BrowserExtension
{
Q_OBJECT
+ TQ_OBJECT
public:
KonqSidebarBrowserExtension(KonqSidebar *part_,Sidebar_Widget *widget_,const char *name):
KParts::BrowserExtension((KParts::ReadOnlyPart*)part_,name),widget(widget_){;}
@@ -73,6 +74,7 @@ class KonqSidebarBrowserExtension : public KParts::BrowserExtension
class KonqSidebar : public KParts::ReadOnlyPart, public KonqSidebarIface
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Default constructor
@@ -110,6 +112,7 @@ class KAboutData;
class KonqSidebarFactory : public KParts::Factory
{
Q_OBJECT
+ TQ_OBJECT
public:
KonqSidebarFactory();
virtual ~KonqSidebarFactory();
diff --git a/konqueror/sidebar/konqsidebarplugin.cpp b/konqueror/sidebar/konqsidebarplugin.cpp
index 1839425dc..0f3fdddde 100644
--- a/konqueror/sidebar/konqsidebarplugin.cpp
+++ b/konqueror/sidebar/konqsidebarplugin.cpp
@@ -52,7 +52,7 @@ void KonqSidebarPlugin::handlePreviewOnMouseOver(const KFileItem& /*items*/) {}
bool KonqSidebarPlugin::universalMode() {
if (!parent()) return false;
- KonqSidebarIface *ksi=static_cast<KonqSidebarIface*>(tqparent()->tqqt_cast("KonqSidebarIface"));
+ KonqSidebarIface *ksi=static_cast<KonqSidebarIface*>(tqparent()->qt_cast("KonqSidebarIface"));
if (!ksi) return false;
kdDebug()<<"calling KonqSidebarIface->universalMode()"<<endl;
return ksi->universalMode();
diff --git a/konqueror/sidebar/sidebar_widget.cpp b/konqueror/sidebar/sidebar_widget.cpp
index 50163c46a..e69504367 100644
--- a/konqueror/sidebar/sidebar_widget.cpp
+++ b/konqueror/sidebar/sidebar_widget.cpp
@@ -178,13 +178,13 @@ void addBackEnd::activatedAddMenu(int id)
KLibLoader *loader = KLibLoader::self();
// try to load the library
- TQString libname = *libNames.at(id);
+ TQString libname = *libNames.tqat(id);
KLibrary *lib = loader->library(TQFile::encodeName(libname));
if (lib)
{
// get the create_ function
TQString factory("add_");
- factory = factory+(*libNames.at(id));
+ factory = factory+(*libNames.tqat(id));
void *add = lib->symbol(TQFile::encodeName(factory));
if (add)
@@ -194,7 +194,7 @@ void addBackEnd::activatedAddMenu(int id)
TQMap<TQString,TQString> map;
func = (bool (*)(TQString*, TQString*, TQMap<TQString,TQString> *)) add;
TQString *tmp = new TQString("");
- if (func(tmp,libParam.at(id),&map))
+ if (func(tmp,libParam.tqat(id),&map))
{
TQString myFile = findFileName(tmp,m_universal,m_currentProfile);
@@ -219,7 +219,7 @@ void addBackEnd::activatedAddMenu(int id)
delete tmp;
}
} else {
- kdWarning() << "libname:" << libNames.at(id)
+ kdWarning() << "libname:" << libNames.tqat(id)
<< " doesn't specify a library!" << endl;
}
}
@@ -574,7 +574,7 @@ void Sidebar_Widget::activatedMenu(int id)
{
int tmpViewID=m_latestViewed;
for (uint i=0; i<m_buttons.count(); i++) {
- ButtonInfo *button = m_buttons.at(i);
+ ButtonInfo *button = m_buttons.tqat(i);
if ((int) i != tmpViewID)
{
if (button->dock && button->dock->isVisibleTo(this))
@@ -598,7 +598,7 @@ void Sidebar_Widget::activatedMenu(int id)
m_mainDockWidget->show();
if ((tmpLatestViewed>=0) && (tmpLatestViewed < (int) m_buttons.count()))
{
- ButtonInfo *button = m_buttons.at(tmpLatestViewed);
+ ButtonInfo *button = m_buttons.tqat(tmpLatestViewed);
if (button && button->dock)
{
m_noUpdate=true;
@@ -694,7 +694,7 @@ void Sidebar_Widget::updateButtons()
{
for (uint i = 0; i < m_buttons.count(); i++)
{
- ButtonInfo *button = m_buttons.at(i);
+ ButtonInfo *button = m_buttons.tqat(i);
if (button->dock)
{
m_noUpdate = true;
@@ -742,7 +742,7 @@ void Sidebar_Widget::createButtons()
for (uint i = 0; i < m_buttons.count(); i++)
{
- ButtonInfo *button = m_buttons.at(i);
+ ButtonInfo *button = m_buttons.tqat(i);
if (m_openViews.tqcontains(button->file))
{
m_buttonBar->setTab(i,true);
@@ -763,7 +763,7 @@ bool Sidebar_Widget::openURL(const class KURL &url)
if (url.protocol()=="sidebar")
{
for (unsigned int i=0;i<m_buttons.count();i++)
- if (m_buttons.at(i)->file==url.path())
+ if (m_buttons.tqat(i)->file==url.path())
{
KMultiTabBarTab *tab = m_buttonBar->tab(i);
if (!tab->isOn())
@@ -778,7 +778,7 @@ bool Sidebar_Widget::openURL(const class KURL &url)
bool ret = false;
for (unsigned int i=0;i<m_buttons.count();i++)
{
- ButtonInfo *button = m_buttons.at(i);
+ ButtonInfo *button = m_buttons.tqat(i);
if (button->dock)
{
if ((button->dock->isVisibleTo(this)) && (button->module))
@@ -836,7 +836,7 @@ bool Sidebar_Widget::eventFilter(TQObject *obj, TQEvent *ev)
if (ev->type()==TQEvent::MouseButtonPress && ((TQMouseEvent *)ev)->button()==Qt::RightButton)
{
- KMultiTabBarTab *bt=dynamic_cast<KMultiTabBarTab*>(obj);
+ KMultiTabBarTab *bt=tqt_dynamic_cast<KMultiTabBarTab*>(obj);
if (bt)
{
kdDebug()<<"Request for popup"<<endl;
@@ -845,7 +845,7 @@ bool Sidebar_Widget::eventFilter(TQObject *obj, TQEvent *ev)
{
if (bt==m_buttonBar->tab(i))
{
- m_currentButton = m_buttons.at(i);
+ m_currentButton = m_buttons.tqat(i);
break;
}
}
@@ -953,7 +953,7 @@ bool Sidebar_Widget::createView( ButtonInfo *data)
void Sidebar_Widget::showHidePage(int page)
{
- ButtonInfo *info = m_buttons.at(page);
+ ButtonInfo *info = m_buttons.tqat(page);
if (!info->dock)
{
if (m_buttonBar->isTabRaised(page))
@@ -1072,7 +1072,7 @@ void Sidebar_Widget::dockWidgetHasUndocked(KDockWidget* wid)
kdDebug()<<" Sidebar_Widget::dockWidgetHasUndocked(KDockWidget*)"<<endl;
for (unsigned int i=0;i<m_buttons.count();i++)
{
- ButtonInfo *button = m_buttons.at(i);
+ ButtonInfo *button = m_buttons.tqat(i);
if (button->dock==wid)
{
if (m_buttonBar->isTabRaised(i))
@@ -1255,7 +1255,7 @@ Sidebar_Widget::~Sidebar_Widget()
m_noUpdate = true;
for (uint i=0;i<m_buttons.count();i++)
{
- ButtonInfo *button = m_buttons.at(i);
+ ButtonInfo *button = m_buttons.tqat(i);
if (button->dock)
button->dock->undock();
}
diff --git a/konqueror/sidebar/trees/bookmark_module/bookmark_module.cpp b/konqueror/sidebar/trees/bookmark_module/bookmark_module.cpp
index e79ed82df..b0d818c62 100644
--- a/konqueror/sidebar/trees/bookmark_module/bookmark_module.cpp
+++ b/konqueror/sidebar/trees/bookmark_module/bookmark_module.cpp
@@ -413,9 +413,9 @@ void KonqSidebarBookmarkModule::slotCopyLocation()
if ( !bookmark.isGroup() )
{
kapp->tqclipboard()->setData( KBookmarkDrag::newDrag(bookmark, 0),
- QClipboard::Selection );
+ TQClipboard::Selection );
kapp->tqclipboard()->setData( KBookmarkDrag::newDrag(bookmark, 0),
- QClipboard::Clipboard );
+ TQClipboard::Clipboard );
}
}
@@ -490,7 +490,7 @@ void KonqSidebarBookmarkModule::fillGroup( KonqSidebarTreeItem * parentItem, KBo
item->setOpen(false);
}
else if ( bk.isSeparator() )
- item->setVisible( false );
+ item->tqsetVisible( false );
else
item->setExpandable( false );
}
diff --git a/konqueror/sidebar/trees/konq_sidebartree.cpp b/konqueror/sidebar/trees/konq_sidebartree.cpp
index 9b342f20e..404a2f2c5 100644
--- a/konqueror/sidebar/trees/konq_sidebartree.cpp
+++ b/konqueror/sidebar/trees/konq_sidebartree.cpp
@@ -1031,8 +1031,8 @@ void KonqSidebarTree::slotCopyLocation()
{
if (!m_currentTopLevelItem) return;
KURL url = m_currentTopLevelItem->externalURL();
- kapp->tqclipboard()->setData( new KURLDrag(url, 0), QClipboard::Selection );
- kapp->tqclipboard()->setData( new KURLDrag(url, 0), QClipboard::Clipboard );
+ kapp->tqclipboard()->setData( new KURLDrag(url, 0), TQClipboard::Selection );
+ kapp->tqclipboard()->setData( new KURLDrag(url, 0), TQClipboard::Clipboard );
}
///////////////////////////////////////////////////////////////////
diff --git a/konqueror/sidebar/trees/konqsidebar_tree.cpp b/konqueror/sidebar/trees/konqsidebar_tree.cpp
index 2711c723a..fc53039b6 100644
--- a/konqueror/sidebar/trees/konqsidebar_tree.cpp
+++ b/konqueror/sidebar/trees/konqsidebar_tree.cpp
@@ -150,7 +150,7 @@ extern "C"
{
int id=names.tqfindIndex( item );
if (id==-1) return false;
- KSimpleConfig ksc2(*list.at(id));
+ KSimpleConfig ksc2(*list.tqat(id));
ksc2.setGroup("Desktop Entry");
map->insert("Type","Link");
map->insert("Icon",ksc2.readEntry("Icon"));
diff --git a/konqueror/konq_tabs.cc b/konqueror/konq_tabs.cc
index 09d1a0b53..3fb199d88 100644
--- a/konqueror/konq_tabs.cc
+++ b/konqueror/konq_tabs.cc
@@ -218,7 +218,7 @@ void KonqFrameTabs::copyHistory( KonqFrameBase *other )
for (uint i = 0; i < m_pChildFrameList->count(); i++ )
{
- m_pChildFrameList->at(i)->copyHistory( static_cast<KonqFrameTabs *>( other )->m_pChildFrameList->at(i) );
+ m_pChildFrameList->tqat(i)->copyHistory( static_cast<KonqFrameTabs *>( other )->m_pChildFrameList->tqat(i) );
}
}
@@ -234,7 +234,7 @@ void KonqFrameTabs::printFrameInfo( const TQString& spaces )
KonqFrameBase* child;
int childFrameCount = m_pChildFrameList->count();
for (int i = 0 ; i < childFrameCount ; i++) {
- child = m_pChildFrameList->at(i);
+ child = m_pChildFrameList->tqat(i);
if (child != 0L)
child->printFrameInfo(spaces + " ");
else
@@ -322,7 +322,7 @@ void KonqFrameTabs::removeChildFrame( KonqFrameBase * frame )
void KonqFrameTabs::slotCurrentChanged( TQWidget* newPage )
{
setTabColor( newPage, KGlobalSettings::textColor() );
- KonqFrameBase* currentFrame = dynamic_cast<KonqFrameBase*>(newPage);
+ KonqFrameBase* currentFrame = tqt_dynamic_cast<KonqFrameBase*>(newPage);
if (currentFrame && !m_pViewManager->isLoadingProfile()) {
m_pActiveChild = currentFrame;
@@ -346,11 +346,11 @@ void KonqFrameTabs::moveTabForward( int index )
void KonqFrameTabs::slotMovedTab( int from, int to )
{
- KonqFrameBase* fromFrame = m_pChildFrameList->at( from );
+ KonqFrameBase* fromFrame = m_pChildFrameList->tqat( from );
m_pChildFrameList->remove( fromFrame );
m_pChildFrameList->insert( to, fromFrame );
- KonqFrameBase* currentFrame = dynamic_cast<KonqFrameBase*>( currentPage() );
+ KonqFrameBase* currentFrame = tqt_dynamic_cast<KonqFrameBase*>( currentPage() );
if ( currentFrame && !m_pViewManager->isLoadingProfile() ) {
m_pActiveChild = currentFrame;
currentFrame->activateChild();
@@ -383,11 +383,11 @@ void KonqFrameTabs::slotContextMenu( TQWidget *w, const TQPoint &p )
m_pPopupMenu->setItemEnabled( OTHERTABS_ID, tabCount>1 );
m_pSubPopupMenuTab->setItemEnabled( m_closeOtherTabsId, true );
// Yes, I know this is an unchecked dynamic_cast - I'm casting sideways in a
// class hierarchy and it could crash one day, but I haven't checked
// setWorkingTab so I don't know if it can handle nulls.
- m_pViewManager->mainWindow()->setWorkingTab( dynamic_cast<KonqFrameBase*>(w) );
+ m_pViewManager->mainWindow()->setWorkingTab( tqt_dynamic_cast<KonqFrameBase*>(w) );
m_pPopupMenu->exec( p );
}
@@ -427,8 +427,8 @@ void KonqFrameTabs::refreshSubPopupMenuTab()
void KonqFrameTabs::slotCloseRequest( TQWidget *w )
{
if ( m_pChildFrameList->count() > 1 ) {
- // Yes, I know this is an unchecked dynamic_cast - I'm casting sideways in a class hierarchy and it could crash one day, but I haven't checked setWorkingTab so I don't know if it can handle nulls.
- m_pViewManager->mainWindow()->setWorkingTab( dynamic_cast<KonqFrameBase*>(w) );
+ // Yes, I know this is an unchecked tqt_dynamic_cast - I'm casting sideways in a class hierarchy and it could crash one day, but I haven't checked setWorkingTab so I don't know if it can handle nulls.
+ m_pViewManager->mainWindow()->setWorkingTab( tqt_dynamic_cast<KonqFrameBase*>(w) );
emit ( removeTabPopup() );
}
}
@@ -440,8 +440,8 @@ void KonqFrameTabs::slotSubPopupMenuTabActivated( int _id)
void KonqFrameTabs::slotMouseMiddleClick()
{
- TQApplication::tqclipboard()->setSelectionMode( QClipboard::Selection );
- KURL filteredURL ( KonqMisc::konqFilteredURL( this, TQApplication::clipboard()->text() ) );
+ TQApplication::tqclipboard()->setSelectionMode( TQClipboard::Selection );
+ KURL filteredURL ( KonqMisc::konqFilteredURL( this, TQApplication::tqclipboard()->text() ) );
if ( !filteredURL.isEmpty() ) {
KonqView* newView = m_pViewManager->addTab(TQString::null, TQString::null, false, false);
if (newView == 0L) return;
@@ -455,16 +455,16 @@ void KonqFrameTabs::slotMouseMiddleClick( TQWidget *w )
{
if ( m_MouseMiddleClickClosesTab ) {
if ( m_pChildFrameList->count() > 1 ) {
- // Yes, I know this is an unchecked dynamic_cast - I'm casting sideways in a class hierarchy and it could crash one day, but I haven't checked setWorkingTab so I don't know if it can handle nulls.
- m_pViewManager->mainWindow()->setWorkingTab( dynamic_cast<KonqFrameBase*>(w) );
+ // Yes, I know this is an unchecked tqt_dynamic_cast - I'm casting sideways in a class hierarchy and it could crash one day, but I haven't checked setWorkingTab so I don't know if it can handle nulls.
+ m_pViewManager->mainWindow()->setWorkingTab( tqt_dynamic_cast<KonqFrameBase*>(w) );
emit ( removeTabPopup() );
}
}
else {
- TQApplication::tqclipboard()->setSelectionMode( QClipboard::Selection );
- KURL filteredURL ( KonqMisc::konqFilteredURL( this, TQApplication::clipboard()->text() ) );
+ TQApplication::tqclipboard()->setSelectionMode( TQClipboard::Selection );
+ KURL filteredURL ( KonqMisc::konqFilteredURL( this, TQApplication::tqclipboard()->text() ) );
if ( !filteredURL.isEmpty() ) {
- KonqFrameBase* frame = dynamic_cast<KonqFrameBase*>(w);
+ KonqFrameBase* frame = tqt_dynamic_cast<KonqFrameBase*>(w);
if (frame) {
m_pViewManager->mainWindow()->openURL( frame->activeChildView(), filteredURL );
}
@@ -494,7 +494,7 @@ void KonqFrameTabs::slotReceivedDropEvent( TQWidget *w, TQDropEvent *e )
{
KURL::List lstDragURLs;
bool ok = KURLDrag::decode( e, lstDragURLs );
- KonqFrameBase* frame = dynamic_cast<KonqFrameBase*>(w);
+ KonqFrameBase* frame = tqt_dynamic_cast<KonqFrameBase*>(w);
if ( ok && lstDragURLs.first().isValid() && frame ) {
KURL lstDragURL = lstDragURLs.first();
if ( lstDragURL != frame->activeChildView()->url() )
@@ -504,7 +504,7 @@ void KonqFrameTabs::slotReceivedDropEvent( TQWidget *w, TQDropEvent *e )
void KonqFrameTabs::slotInitiateDrag( TQWidget *w )
{
- KonqFrameBase* frame = dynamic_cast<KonqFrameBase*>( w );
+ KonqFrameBase* frame = tqt_dynamic_cast<KonqFrameBase*>( w );
if (frame) {
KURL::List lst;
lst.append( frame->activeChildView()->url() );
@@ -383,11 +383,11 @@ void KonqFrameTabs::slotContextMenu( TQWidget *w, const TQPoint &p )
m_pPopupMenu->setItemEnabled( OTHERTABS_ID, tabCount>1 );
m_pSubPopupMenuTab->setItemEnabled( m_closeOtherTabsId, true );
- // Yes, I know this is an unchecked dynamic_cast - I'm casting sideways in a
+ // Yes, I know this is an unchecked tqt_dynamic_cast - I'm casting sideways in a
// class hierarchy and it could crash one day, but I haven't checked
// setWorkingTab so I don't know if it can handle nulls.